@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="UTF-8"?>
+<?xml version="1.0"?>
 <app>
 
 <category>
@@ -78,11 +78,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-
+echo "deb http://deb.debian.org/debian trixie-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+apt-get update
 </preinstall>
 
 <install_package_names>
--t bookworm-backports libreoffice-base-core
+-t trixie-backports libreoffice-base-core
 libreoffice-calc
 libreoffice-draw
 libreoffice-impress
@@ -91,12 +92,12 @@ libreoffice-writer
 libreoffice-base
 libreoffice-l10n-zh-tw
 libreoffice-help-zh-tw
-libreoffice-java-common
 libreoffice-gtk3
 </install_package_names>
 
 <postinstall>
-
+rm /etc/apt/sources.list.d/pitemp.list
+apt-get update
 </postinstall>
 
 <uninstall_package_names>
@@ -106,7 +107,6 @@ libreoffice-draw
 libreoffice-impress
 libreoffice-math
 libreoffice-writer
-libreoffice-java-common
 libreoffice-base
 libreoffice-l10n-zh-tw
 libreoffice-help-zh-tw
