@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="UTF-8"?>
+<?xml version="1.0"?>
 <app>
 
 <category>
@@ -78,15 +78,17 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-
+echo "deb http://deb.debian.org/debian trixie-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+apt-get update
 </preinstall>
 
 <install_package_names>
--t bookworm-backports libreoffice-l10n-en-za
+-t trixie-backports libreoffice-l10n-en-za
 </install_package_names>
 
 <postinstall>
-
+rm /etc/apt/sources.list.d/pitemp.list
+apt-get update
 </postinstall>
 
 <uninstall_package_names>
