@@ -78,26 +78,22 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys E1C726CD
-echo "deb http://mxrepo.com/mx/repo/ bullseye main non-free">/etc/apt/sources.list.d/pitemp1.list
-sleep .1
-echo "deb http://mxrepo.com/mx/testrepo/ bullseye test ">/etc/apt/sources.list.d/pitemp.list
-apt-get update
+
 </preinstall>
 
 <install_package_names>
--t mx gimp
+gimp
+gimp-data-extras
 </install_package_names>
 
 
 <postinstall>
-rm /etc/apt/sources.list.d/pitemp.list
-rm /etc/apt/sources.list.d/pitemp1.list
-apt-get update
+
 </postinstall>
 
 
 <uninstall_package_names>
 gimp
+gimp-data-extras
 </uninstall_package_names>
 </app>
