@@ -82,7 +82,7 @@ all
 </preinstall>
 
 <install_package_names>
-papiris-mini-antix
+papirus-mini-antix
 </install_package_names>
 
 
@@ -92,6 +92,6 @@ papiris-mini-antix
 
 
 <uninstall_package_names>
-papiris-mini-antix
+papirus-mini-antix
 </uninstall_package_names>
 </app>
